@@ -11,7 +11,7 @@ use parking_lot::Mutex;
 use rayon::iter::{IntoParallelRefIterator, ParallelIterator};
 use tinymist::project::*;
 use tinymist::tool::project::{StartProjectResult, start_project};
-use tinymist::world::{SourceWorld, with_main};
+use tinymist::world::{PngExportArgs, SourceWorld, with_main};
 use tinymist_debug::CoverageResult;
 use tinymist_project::world::{DiagnosticFormat, system::print_diagnostics};
 use tinymist_query::analysis::Analysis;
@@ -68,10 +68,6 @@ pub struct TestConfigArgs {
     #[clap(long)]
     pub update: bool,
 
-    /// The argument to export to PNG.
-    #[clap(flatten)]
-    pub png: PngExportArgs,
-
     /// Whether to collect coverage.
     #[clap(long)]
     pub coverage: bool,
@@ -137,6 +133,7 @@ pub async fn test_main(args: TestArgs) -> Result<()> {
     let config = TestContext {
         root,
         args: args.config,
+        png: args.compile.png,
         out_file,
         analysis: Analysis::default(),
     };
@@ -222,12 +219,14 @@ pub async fn test_main(args: TestArgs) -> Result<()> {
 }
 
 fn test_once(world: &LspWorld, ctx: &TestContext) -> Result<bool> {
-    let mut actx = ctx.analysis.enter(world.clone());
-    let doc = typst::compile::<TypstPagedDocument>(&actx.world).output?;
+    let doc = typst_shim::compile_opt::<TypstPagedDocument>(&world).output?;
+
+    let mut snap = CompileSnapshot::from_world(world.clone());
+    snap.success_doc = Some(TypstDocument::Paged(Arc::new(doc)));
+    let mut actx = ctx.analysis.enter(WorldComputeGraph::new(snap));
 
     let suites =
-        tinymist_query::testing::test_suites(&mut actx, &TypstDocument::from(Arc::new(doc)))
-            .context("failed to discover tests")?;
+        tinymist_query::testing::test_suites(&mut actx).context("failed to discover tests")?;
     log_info!(
         "Found {} tests and {} examples",
         suites.tests.len(),
@@ -266,6 +265,7 @@ struct TestContext {
     analysis: Analysis,
     root: ImmutPath,
     args: TestConfigArgs,
+    png: PngExportArgs,
     out_file: Option<Arc<Mutex<std::fs::File>>>,
 }
 
@@ -449,7 +449,7 @@ impl<'a> TestRunner<'a> {
     }
 
     fn build_example<T: typst::Document>(&self, world: &dyn World) -> (bool, Option<T>) {
-        let result = typst::compile::<T>(world);
+        let result = typst_shim::compile_opt::<T>(world);
         if !result.warnings.is_empty() {
             self.diagnostics.lock().push(result.warnings);
         }
@@ -468,7 +468,7 @@ impl<'a> TestRunner<'a> {
             return false;
         };
 
-        let ppp = self.ctx.args.png.ppi / 72.0;
+        let ppp = self.ctx.png.ppi / 72.0;
         let pixmap = typst_render::render_merged(doc, ppp, Default::default(), None);
         let output = pixmap.encode_png().context_ut("cannot encode pixmap");
         let output = output.and_then(|output| self.update_example(example, &output, "paged"));
